pub struct HistogramTable(/* private fields */);Expand description
Histograms of tricks taken by all seats in all strains
Each seat contains the same number of entries, which is the total number of solved deals. This invariant is not enforced by the type system, but it is expected to be upheld by the code.
Implementations